==> apeman-proto-app-1.0.0.tgz: package/Apemanfile.js <==
/**
 * Configuration file for apeman projects.
 * @see https://github.com/apeman-labo/apeman
 */

"use strict";

module.exports = {
    /** Current working directory path */
    get $cwd() {
        return __dirname;
    },
    /** Package data. */
    get $pkg() {
        return require('./package.json');
    },
    /** Prototype apps */
    get $proto() {
        return [
            require('apeman-proto-abstract')
        ];
    },
    /**
     * apeman tmpl configurations.
     * @see https://github.com/apeman-labo/apeman-tmpl
     */
    get $tmpls() {
        const robots = require('apeman-tmpl-robots'),
            humans = require('apeman-tmpl-humans'),
            route = require('apeman-tmpl-route');
        return {
            'public/robots.txt': robots({
                disallow: [
                    'error',
                    'tmp',
                    'download'
                ]
            }),
            'public/humans.txt': humans({}),
            'routes/index.js': route({})
        }
    },
    /**
     * apeman task configurations.
     * @see https://github.com/apeman-labo/apeman-task
     */
    get $tasks() {
        const mkdir = require('apeman-task-mkdir'),
            coz = require('apeman-task-coz');

        return {
            'app:mkdir':mkdir([
                'error',
                'public',
                'routes',
                'test'
            ]),
            'app:render': coz([
                '+(error|public|routes|test)/**/.*.bud'
            ])
        }
    },
    /**
     * apeman watch configurations.
     * @see https://github.com/apeman-labo/apeman-wtch
     */
    get $wtchs() {
        return {
            'app~render': {
                pattern: '+(error|public|routes|test)/**/.*.bud',
                action: (ev, filename) => {
                    require('coz').render(filename);
                }
            }
        }
    },
    /** Note about properties. */
    get $notes() {
        return {
            '$tasks.app:mkdir': "Generate directories for app.",
            '$tasks.app:render': "Render bud files.",
            '$wtchs.app~render': "Watch bud files to render."
        }
    },
    /** Commands which need to be installed in advance. */
    get $needs() {
        return {}
    }
};


if (!module.parent) {
    // Execute this file as apeman bin.
    require('apeman').cli(process.argv);
}

==> apeman-proto-app-1.0.2.tgz: package/Apemanfile.js <==
/**
 * Configuration file for apeman projects.
 * @see https://github.com/apeman-labo/apeman
 */

"use strict";

module.exports = {
    /** Current working directory path */
    get $cwd() {
        return __dirname;
    },
    /** Package data. */
    get $pkg() {
        return require('./package.json');
    },
    /** Prototype apps */
    get $proto() {
        return [
            require('apeman-proto-abstract'),
            require('apeman-proto-wtch')
        ];
    },
    /**
     * apeman tmpl configurations.
     * @see https://github.com/apeman-labo/apeman-tmpl
     */
    get $tmpls() {
        const robots = require('apeman-tmpl-robots'),
            humans = require('apeman-tmpl-humans'),
            route = require('apeman-tmpl-route');
        return {
            'public/robots.txt': robots({
                disallow: [
                    'error',
                    'tmp',
                    'download'
                ]
            }),
            'public/humans.txt': humans({}),
            'routes/index.js': route({})
        }
    },
    /**
     * apeman task configurations.
     * @see https://github.com/apeman-labo/apeman-task
     */
    get $tasks() {
        const mkdir = require('apeman-task-mkdir'),
            coz = require('apeman-task-coz');

        return {
            'app:mkdir': mkdir([
                'error',
                'public',
                'routes',
                'test'
            ]),
            'app:render': coz([
                '+(error|public|routes|test)/**/.*.bud'
            ])
        }
    },
    /**
     * apeman watch configurations.
     * @see https://github.com/apeman-labo/apeman-wtch
     */
    get $wtchs() {
        return {
            'app:render': {
                pattern: '+(error|public|routes|test)/**/.*.bud',
                action: (ev, filename) => {
                    require('coz').render(filename);
                }
            }
        }
    },
    /** Note about properties. */
    get $notes() {
        return {
            '$tasks.app:mkdir': "Generate directories for app.",
            '$tasks.app:render': "Render bud files.",
            '$wtchs.app:render': "Watch bud files to render."
        }
    },
    /** Commands which need to be installed in advance. */
    get $needs() {
        return {}
    }
};


if (!module.parent) {
    // Execute this file as apeman bin.
    require('apeman').cli(process.argv);
}
